BodyText constructor

const BodyText({
  1. Key? key,
  2. String text = 'Onairos makes your experience on Onairos Internship Onboarding and everywhere else 1000x better',
  3. bool isDark = false,
  4. TextAlign textAlign = TextAlign.center,
  5. EdgeInsets padding = const EdgeInsets.symmetric(horizontal: OnairosTheme.spacingL),
})

Implementation

const BodyText({
  Key? key,
  this.text = 'Onairos makes your experience on Onairos Internship Onboarding and everywhere else 1000x better',
  this.isDark = false,
  this.textAlign = TextAlign.center,
  this.padding = const EdgeInsets.symmetric(horizontal: OnairosTheme.spacingL),
}) : super(key: key);