TrainingData class

Constructors

TrainingData({required String eta, required double percent, required String status})

Properties

eta → String
final
hashCode → int
The hash code for this object.
no setterinherited
percent → double
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited