OnairosDebugHelper class

Helper class for debug functionality throughout the Onairos package

Constructors

OnairosDebugHelper()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

debugMode ↔ bool
getter/setter pair
logs ↔ List<String>
getter/setter pair

Static Methods

debugButton(BuildContext context) → Widget
init({bool enableDebug = false}) → void
log(String message) → void
showLogsDialog(BuildContext context) → void
testModalPresentation(BuildContext context) → Future<void>