LoadingScreen class

Inheritance

Constructors

LoadingScreen({Key? key, required String appName, required bool emailSubmitted, required TextEditingController emailController, required bool isEmailValid, required bool isEmailSubmitting, required dynamic onEmailChanged(String), required VoidCallback onSubmitEmail, dynamic onResolved(String, String, String)?, bool darkMode = false, Color primaryColor = const Color(0xFF2196F3), required String username, bool testMode = false})
const

Properties

appName → String
final
darkMode → bool
final
emailController → TextEditingController
final
emailSubmitted → bool
final
hashCode → int
The hash code for this object.
no setterinherited
isEmailSubmitting → bool
final
isEmailValid → bool
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
onEmailChanged → dynamic Function(String)
final
onResolved → dynamic Function(String, String, String)?
final
onSubmitEmail → VoidCallback
final
primaryColor → Color
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
testMode → bool
final
username → String
final

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → State<LoadingScreen>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited