LinkedInApifyService class

Calls the backend to store the user's LinkedIn profile URL and trigger Apify scraping.

Constructors

LinkedInApifyService()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

scrapeAndStoreProfileUrl({required String profileUrl}) Future<bool>
Returns true only when backend responds 2xx.