TrainingSocketService class

Service for managing Socket.IO connection for training progress updates

Constructors

TrainingSocketService()

Properties

completionStream → Stream<Map<String, dynamic>>
no setter
errorStream → Stream<String>
no setter
hashCode → int
The hash code for this object.
no setterinherited
isConnected → bool
no setter
progressStream → Stream<Map<String, dynamic>>
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
socketId → String?
no setter
statusStream → Stream<String>
no setter

Methods

connect({String? authToken}) → Future<String?>
Connect to Socket.IO server
disconnect() → void
Disconnect from Socket.IO server
dispose() → void
Dispose resources
emitStartTraining({required String email, String? username, required List<String> platforms}) → bool
Start training using the onairos-npm protocol: connect -> emit start-training with socketId + email/username + platforms.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited