RnSpec class

Design spec derived from onairos-npm-react-native (source of truth). Keep all modal-flow screens using these constants to achieve 1:1 parity.

Constructors

RnSpec()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

acceptActive → const Color
consentBottomPadding → const double
consentTopPadding → const double
grabberColor → const Color
grabberHeight → const double
grabberWidth → const double
grey50 → const Color
grey100 → const Color
grey200 → const Color
grey400 → const Color
grey500 → const Color
grey600 → const Color
grey800 → const Color
horizontalPadding → const double
modalTopRadius → const double
subtitle16 → const TextStyle
surface → const Color
title24 → const TextStyle