BodyText constructor
const
BodyText({
- Key? key,
- String text = 'Onairos makes your experience on Onairos Internship Onboarding and everywhere else 1000x better',
- bool isDark = false,
- TextAlign textAlign = TextAlign.center,
- EdgeInsets padding = const EdgeInsets.symmetric(horizontal: OnairosTheme.spacingL),
Implementation
const BodyText({
Key? key,
this.text = 'Onairos makes your experience on Onairos Internship Onboarding and everywhere else 1000x better',
this.isDark = false,
this.textAlign = TextAlign.center,
this.padding = const EdgeInsets.symmetric(horizontal: OnairosTheme.spacingL),
}) : super(key: key);